pub struct CreditRegistrationPhaseList {
pub phases: Vec<CreditRegistrationPhaseRow>,
pub heartbeat_interval_multiplier: i32,
pub consecutive_failure_limit: i32,
pub paused_globally: bool,
}Fields
phases: Vec<CreditRegistrationPhaseRow>In process then pipeline order, so the grouping is a fold over the list.
heartbeat_interval_multiplier: i32consecutive_failure_limit: i32paused_globally: boolEvery phase is stopped, which is what the kill switch does.